from dataclasses import dataclass


@dataclass(frozen=True)
class UserAgentSupportedParts:
	"""
    A class that holds the different parts of a user agent that are supported.

    Attributes:
        os (list[str]): A list of supported operating systems.
        engine (list[str]): A list of supported rendering engines.
        browser (list[str]): A list of supported browsers.
        apple_webkit_browsers (list[str]): A list of browsers that use the AppleWebKit engine.
        blink_browsers (list[str]): A list of browsers that use the Blink engine.
        gecko_browsers (list[str]): A list of browsers that use the Gecko engine.
    """
	os = ["Windows", "Macintosh", "Linux", "Android", "IOS"]
	engine = ["AppleWebKit", "Gecko", "Blink"]
	browser = ["Chrome", "Firefox", "Safari", "Opera", "Edge", "Yandex"]
	apple_webkit_browsers = ["Safari"]
	blink_browsers = ["Chrome", "Opera", "Edge", "Yandex"]
	gecko_browsers = ["Firefox"]


@dataclass(frozen=True)
class UserAgentOS:
	"""
    A class that holds the different OS specific user agent parts.

    Attributes:
        windows_versions (list[str]): A list of supported Windows versions.
        windows_architectures (list[str]): A list of supported Windows architectures.
        mac_os_intel_versions (list[str]): A list of supported macOS versions for Intel CPUs.
        mac_os_apple_silicon_versions (list[str]): A list of supported macOS versions for Apple Silicon CPUs.
        linux_distributions (list[str]): A list of supported Linux distributions.
        linux_architectures (list[str]): A list of supported Linux architectures.
        android_versions (list[str]): A list of supported Android versions.
        android_devices (list[str]): A list of supported Android devices.
        ios_versions (list[str]): A list of supported iOS versions.
        ios_devices (list[tuple[str, str]]): A list of supported iOS devices and their prefixes.
    """
	windows_versions = [
		"NT 10.0",
		"NT 6.3",
		"NT 6.2",
		"NT 6.1",
		"NT 6.0",
		"NT 5.2",
		"NT 5.1",
		"NT 5.0"
	]
	
	windows_architectures = ["Win64; x64", "Win32", "WOW64"]
	
	linux_distributions = [
		"Debian",
		"Ubuntu",
		"Kubuntu",
		"Xubuntu",
		"Lubuntu",
		"Ubuntu MATE",
		"Ubuntu Budgie",
		"Ubuntu Studio",
		"Red Hat Enterprise Linux",
		"CentOS Stream",
		"Rocky Linux",
		"AlmaLinux",
		"Fedora",
		"Arch",
		"Manjaro",
		"EndeavourOS",
		"Artix",
		None
	]
	
	linux_architectures = [
		"x86_64",
		"i686",
		"armv7l",
		"aarch64",
		"armv6l",
		"armv5tel",
		"ppc",
		"ppc64",
		"ppc64le",
		"mips",
		"mips64",
		"mipsel",
		"mips64el",
		"riscv64",
		"s390x",
		"sparc",
		"sparc64",
		"sh4",
		"ia64",
		"loongarch64"
	]
	
	mac_os_intel_versions = [
		"10_11_0",
		"10_11_1",
		"10_11_2",
		"10_11_3",
		"10_11_4",
		"10_11_5",
		"10_11_6",
		"10_12_0",
		"10_12_1",
		"10_12_2",
		"10_12_3",
		"10_12_4",
		"10_12_5",
		"10_12_6",
		"10_13_0",
		"10_13_1",
		"10_13_3",
		"10_13_4",
		"10_13_5",
		"10_13_6",
		"10_14_0",
		"10_14_1",
		"10_14_2",
		"10_14_3",
		"10_14_4",
		"10_14_5",
		"10_14_6",
		"10_15_0",
		"10_15_1",
		"10_15_2",
		"10_15_3",
		"10_15_4",
		"10_15_5",
		"10_15_6",
		"10_15_7",
		"11_0",
		"11_0_1",
		"11_1",
		"11_2",
		"11_2_1",
		"11_2_2",
		"11_2_3",
		"11_3",
		"11_3_1",
		"11_4",
		"11_5",
		"11_5_1",
		"11_5_2",
		"11_6",
		"11_6_1",
		"11_6_2",
		"11_6_3",
		"11_6_4",
		"11_6_5",
		"11_6_6",
		"11_6_7",
		"11_6_8",
		"11_7",
		"11_7_1",
		"11_7_2",
		"11_7_3",
		"11_7_4",
		"11_7_5",
		"11_7_6",
		"11_7_7",
		"11_7_8",
		"11_7_9",
		"11_7_10",
		"12_0",
		"12_0_1",
		"12_1",
		"12_2",
		"12_2_1",
		"12_3",
		"12_3_1",
		"12_4",
		"12_5",
		"12_5_1",
		"12_6",
		"12_6_1",
		"12_6_2",
		"12_6_3",
		"12_6_4",
		"12_6_5",
		"12_6_6",
		"12_6_7",
		"12_6_8",
		"12_6_9",
		"12_7",
		"12_7_1",
		"12_7_2",
		"12_7_3",
		"12_7_4",
		"12_7_5",
		"12_7_6",
		"13_0",
		"13_0_1",
		"13_1",
		"13_2",
		"13_2_1",
		"13_3",
		"13_3_1",
		"13_4",
		"13_4_1",
		"13_5",
		"13_5_1",
		"13_5_2",
		"13_6",
		"13_6_1",
		"13_6_2",
		"13_6_3",
		"13_6_4",
		"13_6_5",
		"13_6_6",
		"13_6_7",
		"13_6_8",
		"13_6_9",
		"13_7",
		"13_7_1",
		"13_7_2",
		"13_7_3",
		"14_0",
		"14_1",
		"14_1_1",
		"14_1_2",
		"14_2",
		"14_2_1",
		"14_3",
		"14_3_1",
		"14_4",
		"14_4_1",
		"14_5",
		"14_6",
		"14_6_1",
		"14_7",
		"14_7_1",
		"14_7_2"
	]
	
	mac_os_apple_silicon_versions = [
		"15_0",
		"15_1",
		"15_1_1",
		"15_1_2",
		"15_2",
		"15_2_1",
		"15_3",
		"15_3_1",
		"15_4",
		"15_4_1",
		"15_5",
		"15_6",
		"15_6_1",
		"15_7",
		"15_7_1",
		"15_7_2"
	]
	
	android_versions = [
		"6.0",
		"6.0.1",
		"7.0",
		"7.0.1",
		"7.1",
		"7.1.1",
		"7.1.2",
		"8.0",
		"8.1",
		"9",
		"10",
		"11",
		"12",
		"12L",
		"13",
		"14",
		"15"
	]
	
	android_devices = [
		"Samsung Galaxy S6",
		"Samsung Galaxy S7",
		"Samsung Galaxy S8",
		"Samsung Galaxy S9",
		"Samsung Galaxy S10",
		"Samsung Galaxy S20",
		"Samsung Galaxy S21",
		"Samsung Galaxy S22",
		"Samsung Galaxy S23",
		"Samsung Galaxy S6+",
		"Samsung Galaxy S7+",
		"Samsung Galaxy S8+",
		"Samsung Galaxy S9+",
		"Samsung Galaxy S10+",
		"Samsung Galaxy S20+",
		"Samsung Galaxy S21+",
		"Samsung Galaxy S22+",
		"Samsung Galaxy S23+",
		"Samsung Galaxy S6 Ultra",
		"Samsung Galaxy S7 Ultra",
		"Samsung Galaxy S8 Ultra",
		"Samsung Galaxy S9 Ultra",
		"Samsung Galaxy S10 Ultra",
		"Samsung Galaxy S20 Ultra",
		"Samsung Galaxy S21 Ultra",
		"Samsung Galaxy S22 Ultra",
		"Samsung Galaxy S23 Ultra",
		"Samsung Galaxy S6 e",
		"Samsung Galaxy S7 e",
		"Samsung Galaxy S8 e",
		"Samsung Galaxy S9 e",
		"Samsung Galaxy S10 e",
		"Samsung Galaxy S20 FE",
		"Samsung Galaxy S21 FE",
		"Samsung Galaxy Note 5",
		"Samsung Galaxy Note 7",
		"Samsung Galaxy Note 8",
		"Samsung Galaxy Note 9",
		"Samsung Galaxy Note 10",
		"Samsung Galaxy Note 20",
		"Samsung Galaxy Note 5+",
		"Samsung Galaxy Note 7+",
		"Samsung Galaxy Note 8+",
		"Samsung Galaxy Note 9+",
		"Samsung Galaxy Note 10+",
		"Samsung Galaxy Note 20+",
		"Samsung Galaxy Note 5 Ultra",
		"Samsung Galaxy Note 7 Ultra",
		"Samsung Galaxy Note 8 Ultra",
		"Samsung Galaxy Note 9 Ultra",
		"Samsung Galaxy Note 10 Ultra",
		"Samsung Galaxy Note 20 Ultra",
		"Samsung Galaxy A3",
		"Samsung Galaxy A5",
		"Samsung Galaxy A7",
		"Samsung Galaxy A8",
		"Samsung Galaxy A9",
		"Samsung Galaxy A10",
		"Samsung Galaxy A20",
		"Samsung Galaxy A30",
		"Samsung Galaxy A40",
		"Samsung Galaxy A50",
		"Samsung Galaxy A60",
		"Samsung Galaxy A70",
		"Samsung Galaxy A80",
		"Samsung Galaxy A90",
		"Samsung Galaxy A11",
		"Samsung Galaxy A21",
		"Samsung Galaxy A31",
		"Samsung Galaxy A41",
		"Samsung Galaxy A51",
		"Samsung Galaxy A71",
		"Samsung Galaxy A12",
		"Samsung Galaxy A22",
		"Samsung Galaxy A32",
		"Samsung Galaxy A42",
		"Samsung Galaxy A52",
		"Samsung Galaxy A72",
		"Samsung Galaxy A13",
		"Samsung Galaxy A23",
		"Samsung Galaxy A33",
		"Samsung Galaxy A53",
		"Samsung Galaxy A73",
		"Samsung Galaxy A14",
		"Samsung Galaxy A24",
		"Samsung Galaxy A34",
		"Samsung Galaxy A54",
		"Samsung Galaxy A3s",
		"Samsung Galaxy A5s",
		"Samsung Galaxy A7s",
		"Samsung Galaxy M10",
		"Samsung Galaxy M20",
		"Samsung Galaxy M30",
		"Samsung Galaxy M40",
		"Samsung Galaxy M11",
		"Samsung Galaxy M21",
		"Samsung Galaxy M31",
		"Samsung Galaxy M41",
		"Samsung Galaxy M51",
		"Samsung Galaxy M02",
		"Samsung Galaxy M12",
		"Samsung Galaxy M22",
		"Samsung Galaxy M32",
		"Samsung Galaxy M52",
		"Samsung Galaxy M23",
		"Samsung Galaxy M33",
		"Samsung Galaxy M53",
		"Samsung Galaxy Z Fold",
		"Samsung Galaxy Z Fold 2",
		"Samsung Galaxy Z Fold 3",
		"Samsung Galaxy Z Fold 4",
		"Samsung Galaxy Z Fold 5",
		"Samsung Galaxy Z Flip",
		"Samsung Galaxy Z Flip 2",
		"Samsung Galaxy Z Flip 3",
		"Samsung Galaxy Z Flip 4",
		"Samsung Galaxy Z Flip 5",
		"Samsung Galaxy XCover",
		"Samsung Galaxy F",
		"Google Pixel",
		"Google Pixel XL",
		"Google Pixel 2",
		"Google Pixel 2 XL",
		"Google Pixel 3",
		"Google Pixel 3 XL",
		"Google Pixel 3a",
		"Google Pixel 3a XL",
		"Google Pixel 4",
		"Google Pixel 4 XL",
		"Google Pixel 4a",
		"Google Pixel 4a 5G",
		"Google Pixel 5",
		"Google Pixel 5a",
		"Google Pixel 6",
		"Google Pixel 6 Pro",
		"Google Pixel 6a",
		"Google Pixel 7",
		"Google Pixel 7 Pro",
		"Google Pixel 7a",
		"Google Pixel 8",
		"Google Pixel 8 Pro",
		"Google Nexus 5X",
		"Google Nexus 6P",
		"Poco F1",
		"Poco F2 Pro",
		"Poco F3",
		"Poco F4",
		"Poco F5",
		"Poco F5 Pro",
		"Poco X2",
		"Poco X3",
		"Poco X3 NFC",
		"Poco X3 Pro",
		"Poco X4 Pro",
		"Poco X5",
		"Poco X5 Pro",
		"Poco M2",
		"Poco M2 Pro",
		"Poco M3",
		"Poco M3 Pro",
		"Poco M4 Pro",
		"Poco M5",
		"Poco M5s",
		"Poco M6 Pro",
		"Poco C3",
		"Poco C31",
		"Poco C40",
		"Poco C50",
		"Poco C51",
		"Poco C55",
		"Vivo X5",
		"Vivo X6",
		"Vivo X7",
		"Vivo X9",
		"Vivo X20",
		"Vivo X21",
		"Vivo X23",
		"Vivo X27",
		"Vivo X30",
		"Vivo X50",
		"Vivo X60",
		"Vivo X70",
		"Vivo X80",
		"Vivo X90",
		"Vivo X5 Pro",
		"Vivo X6 Pro",
		"Vivo X7 Pro",
		"Vivo X9 Pro",
		"Vivo X20 Pro",
		"Vivo X21 Pro",
		"Vivo X23 Pro",
		"Vivo X27 Pro",
		"Vivo X30 Pro",
		"Vivo X50 Pro",
		"Vivo X60 Pro",
		"Vivo X70 Pro",
		"Vivo X80 Pro",
		"Vivo X90 Pro",
		"Vivo X5 Plus",
		"Vivo X6 Plus",
		"Vivo X7 Plus",
		"Vivo X9 Plus",
		"Vivo X20 Plus",
		"Vivo X21 Plus",
		"Vivo X23 Plus",
		"Vivo X27 Plus",
		"Vivo X30 Plus",
		"Vivo X50 Plus",
		"Vivo X60 Plus",
		"Vivo X70 Plus",
		"Vivo X80 Plus",
		"Vivo X90 Plus",
		"Vivo V3",
		"Vivo V5",
		"Vivo V7",
		"Vivo V9",
		"Vivo V11",
		"Vivo V15",
		"Vivo V17",
		"Vivo V19",
		"Vivo V20",
		"Vivo V21",
		"Vivo V23",
		"Vivo V25",
		"Vivo V27",
		"Vivo Y11",
		"Vivo Y12",
		"Vivo Y15",
		"Vivo Y17",
		"Vivo Y19",
		"Vivo Y20",
		"Vivo Y30",
		"Vivo Y50",
		"Vivo Y51",
		"Vivo Y52",
		"Vivo Y70",
		"Vivo Y72",
		"Vivo Y73",
		"Vivo Y75",
		"Vivo Y76",
		"Vivo Y81",
		"Vivo Y91",
		"Vivo Y11s",
		"Vivo Y12s",
		"Vivo Y15s",
		"Vivo Y17s",
		"Vivo Y19s",
		"Vivo Y20i",
		"Vivo Y30i",
		"Vivo Y50i",
		"Vivo Y51i",
		"Vivo Y52i",
		"Vivo Y70i",
		"Vivo Y72t",
		"Vivo Y73t",
		"Vivo Y75s",
		"Vivo Y76s",
		"Vivo Y81i",
		"Vivo Y91i",
		"Huawei P9",
		"Huawei P10",
		"Huawei P20",
		"Huawei P30",
		"Huawei P40",
		"Huawei P50",
		"Huawei P60",
		"Huawei P9 Lite",
		"Huawei P10 Lite",
		"Huawei P20 Lite",
		"Huawei P30 Lite",
		"Huawei P40 Lite",
		"Huawei P50 Lite",
		"Huawei P60 Lite",
		"Huawei P9 Pro",
		"Huawei P10 Pro",
		"Huawei P20 Pro",
		"Huawei P30 Pro",
		"Huawei P40 Pro",
		"Huawei P50 Pro",
		"Huawei P60 Pro",
		"Huawei Mate 8",
		"Huawei Mate 9",
		"Huawei Mate 10",
		"Huawei Mate 20",
		"Huawei Mate 30",
		"Huawei Mate 40",
		"Huawei Mate 50",
		"Huawei Mate 8 Lite",
		"Huawei Mate 9 Lite",
		"Huawei Mate 10 Lite",
		"Huawei Mate 20 Lite",
		"Huawei Mate 30 Lite",
		"Huawei Mate 40 Lite",
		"Huawei Mate 50 Lite",
		"Huawei Mate 8 Pro",
		"Huawei Mate 9 Pro",
		"Huawei Mate 10 Pro",
		"Huawei Mate 20 Pro",
		"Huawei Mate 30 Pro",
		"Huawei Mate 40 Pro",
		"Huawei Mate 50 Pro",
		"Huawei Mate RS",
		"Huawei Nova",
		"Huawei Nova 2",
		"Huawei Nova 3",
		"Huawei Nova 4",
		"Huawei Nova 5",
		"Huawei Nova 6",
		"Huawei Nova 7",
		"Huawei Nova 8",
		"Huawei Nova 9",
		"Huawei Nova 10",
		"Huawei Nova 11",
		"Huawei Nova Lite",
		"Huawei Nova 2 Lite",
		"Huawei Nova 3 Lite",
		"Huawei Nova 4 Lite",
		"Huawei Nova 5 Lite",
		"Huawei Nova 6 Lite",
		"Huawei Nova 7 Lite",
		"Huawei Nova 8 Lite",
		"Huawei Nova 9 Lite",
		"Huawei Nova 10 Lite",
		"Huawei Nova 11 Lite",
		"Huawei Nova Pro",
		"Huawei Nova 2 Pro",
		"Huawei Nova 3 Pro",
		"Huawei Nova 4 Pro",
		"Huawei Nova 5 Pro",
		"Huawei Nova 6 Pro",
		"Huawei Nova 7 Pro",
		"Huawei Nova 8 Pro",
		"Huawei Nova 9 Pro",
		"Huawei Nova 10 Pro",
		"Huawei Nova 11 Pro",
		"Redmi Note 3",
		"Redmi Note 4",
		"Redmi Note 5",
		"Redmi Note 6",
		"Redmi Note 7",
		"Redmi Note 8",
		"Redmi Note 9",
		"Redmi Note 10",
		"Redmi Note 11",
		"Redmi Note 12",
		"Redmi Note 3 Pro",
		"Redmi Note 4 Pro",
		"Redmi Note 5 Pro",
		"Redmi Note 6 Pro",
		"Redmi Note 7 Pro",
		"Redmi Note 8 Pro",
		"Redmi Note 9 Pro",
		"Redmi Note 10 Pro",
		"Redmi Note 11 Pro",
		"Redmi Note 12 Pro",
		"Redmi Note 3 Max",
		"Redmi Note 4 Max",
		"Redmi Note 5 Max",
		"Redmi Note 6 Max",
		"Redmi Note 7 Max",
		"Redmi Note 8 Max",
		"Redmi Note 9 Max",
		"Redmi Note 10 Max",
		"Redmi Note 11 Max",
		"Redmi Note 12 Max",
		"Redmi Note 3 S",
		"Redmi Note 4 S",
		"Redmi Note 5 S",
		"Redmi Note 6 S",
		"Redmi Note 7 S",
		"Redmi Note 8 S",
		"Redmi Note 9 S",
		"Redmi Note 10 S",
		"Redmi Note 11 S",
		"Redmi Note 12 S",
		"Redmi Note 10T",
		"Redmi Note 11T",
		"Redmi Note 12T",
		"Redmi Note 10T Pro",
		"Redmi Note 11T Pro",
		"Redmi Note 12T Pro",
		"Redmi Note 10R",
		"Redmi Note 11R",
		"Redmi Note 12R",
		"Redmi Note 10R Pro",
		"Redmi Note 11R Pro",
		"Redmi Note 12R Pro",
		"Redmi 1",
		"Redmi 2",
		"Redmi 3",
		"Redmi 4",
		"Redmi 5",
		"Redmi 6",
		"Redmi 7",
		"Redmi 8",
		"Redmi 9",
		"Redmi 10",
		"Redmi 12",
		"Redmi K20",
		"Redmi K30",
		"Redmi K40",
		"Redmi K50",
		"Redmi K60",
		"Redmi K20 Pro",
		"Redmi K30 Pro",
		"Redmi K40 Pro",
		"Redmi K50 Pro",
		"Redmi K60 Pro",
		"Redmi K20 Ultra",
		"Redmi K30 Ultra",
		"Redmi K40 Ultra",
		"Redmi K50 Ultra",
		"Redmi K60 Ultra",
		"Redmi K20s",
		"Redmi K30s",
		"Redmi K40s",
		"Redmi K50s",
		"Redmi K60s",
		"Xiaomi Mi 5",
		"Xiaomi Mi 6",
		"Xiaomi Mi 8",
		"Xiaomi Mi 9",
		"Xiaomi Mi 10",
		"Xiaomi Mi 11",
		"Xiaomi Mi 12",
		"Xiaomi Mi 13",
		"Xiaomi Mi 5 Pro",
		"Xiaomi Mi 6 Pro",
		"Xiaomi Mi 8 Pro",
		"Xiaomi Mi 9 Pro",
		"Xiaomi Mi 10 Pro",
		"Xiaomi Mi 11 Pro",
		"Xiaomi Mi 12 Pro",
		"Xiaomi Mi 13 Pro",
		"Xiaomi Mi 5 Lite",
		"Xiaomi Mi 6 Lite",
		"Xiaomi Mi 8 Lite",
		"Xiaomi Mi 9 Lite",
		"Xiaomi Mi 10 Lite",
		"Xiaomi Mi 11 Lite",
		"Xiaomi Mi 12 Lite",
		"Xiaomi Mi 13 Lite",
		"Xiaomi Mi 5 Ultra",
		"Xiaomi Mi 6 Ultra",
		"Xiaomi Mi 8 Ultra",
		"Xiaomi Mi 9 Ultra",
		"Xiaomi Mi 10 Ultra",
		"Xiaomi Mi 11 Ultra",
		"Xiaomi Mi 12 Ultra",
		"Xiaomi Mi 13 Ultra",
		"Xiaomi Mix",
		"Xiaomi Mix 2",
		"Xiaomi Mix 3",
		"Xiaomi Mix Alpha",
		"Xiaomi Mix Fold",
		"Black Shark",
		"Black Shark 2",
		"Black Shark 3",
		"Black Shark 4",
		"Black Shark 5",
		"Asus ZenFone 2",
		"Asus ZenFone 3",
		"Asus ZenFone 4",
		"Asus ZenFone 5",
		"Asus ZenFone 6",
		"Asus ZenFone 7",
		"Asus ZenFone 8",
		"Asus ZenFone 9",
		"Asus ZenFone 10",
		"Asus ZenFone 2 Pro",
		"Asus ZenFone 3 Pro",
		"Asus ZenFone 4 Pro",
		"Asus ZenFone 5 Pro",
		"Asus ZenFone 6 Pro",
		"Asus ZenFone 7 Pro",
		"Asus ZenFone 8 Pro",
		"Asus ZenFone 9 Pro",
		"Asus ZenFone 10 Pro",
		"Asus ZenFone 2 Deluxe",
		"Asus ZenFone 3 Deluxe",
		"Asus ZenFone 4 Deluxe",
		"Asus ZenFone 5 Deluxe",
		"Asus ZenFone 6 Deluxe",
		"Asus ZenFone 7 Deluxe",
		"Asus ZenFone 8 Deluxe",
		"Asus ZenFone 9 Deluxe",
		"Asus ZenFone 10 Deluxe",
		"Asus ROG Phone",
		"Asus ROG Phone 2",
		"Asus ROG Phone 3",
		"Asus ROG Phone 5",
		"Asus ROG Phone 6",
		"Asus ROG Phone 7",
		"Asus ROG Phone Pro",
		"Asus ROG Phone 2 Pro",
		"Asus ROG Phone 3 Pro",
		"Asus ROG Phone 5 Pro",
		"Asus ROG Phone 6 Pro",
		"Asus ROG Phone 7 Pro",
		"Asus ROG Phone Ultimate",
		"Asus ROG Phone 2 Ultimate",
		"Asus ROG Phone 3 Ultimate",
		"Asus ROG Phone 5 Ultimate",
		"Asus ROG Phone 6 Ultimate",
		"Asus ROG Phone 7 Ultimate",
		"Realme 1",
		"Realme 2",
		"Realme 3",
		"Realme 5",
		"Realme 6",
		"Realme 7",
		"Realme 8",
		"Realme 9",
		"Realme 10",
		"Realme 11",
		"Realme 1 Pro",
		"Realme 2 Pro",
		"Realme 3 Pro",
		"Realme 5 Pro",
		"Realme 6 Pro",
		"Realme 7 Pro",
		"Realme 8 Pro",
		"Realme 9 Pro",
		"Realme 10 Pro",
		"Realme 11 Pro",
		"Realme 1i",
		"Realme 2i",
		"Realme 3i",
		"Realme 5i",
		"Realme 6i",
		"Realme 7i",
		"Realme 8i",
		"Realme 9i",
		"Realme 10i",
		"Realme 11i",
		"Realme 1s",
		"Realme 2s",
		"Realme 3s",
		"Realme 5s",
		"Realme 6s",
		"Realme 7s",
		"Realme 8s",
		"Realme 9s",
		"Realme 10s",
		"Realme 11s",
		"Realme GT",
		"Realme GT Master Edition",
		"Realme GT Neo",
		"Realme GT Neo 2",
		"Realme GT 3",
		"Realme X",
		"Realme X2",
		"Realme X3",
		"Realme X50",
		"Realme X50 Pro",
		"Realme Narzo",
		"Realme Narzo 20",
		"Realme Narzo 30",
		"Realme Narzo 50",
		"Realme Narzo 60",
		"Oppo Find X",
		"Oppo Find X2",
		"Oppo Find X3",
		"Oppo Find X5",
		"Oppo Find X6",
		"Oppo Find X Pro",
		"Oppo Find X2 Pro",
		"Oppo Find X3 Pro",
		"Oppo Find X5 Pro",
		"Oppo Find X6 Pro",
		"Oppo Reno",
		"Oppo Reno 2",
		"Oppo Reno 3",
		"Oppo Reno 4",
		"Oppo Reno 5",
		"Oppo Reno 6",
		"Oppo Reno 7",
		"Oppo Reno 8",
		"Oppo Reno 9",
		"Oppo Reno 10",
		"Oppo Reno Pro",
		"Oppo Reno 2 Pro",
		"Oppo Reno 3 Pro",
		"Oppo Reno 4 Pro",
		"Oppo Reno 5 Pro",
		"Oppo Reno 6 Pro",
		"Oppo Reno 7 Pro",
		"Oppo Reno 8 Pro",
		"Oppo Reno 9 Pro",
		"Oppo Reno 10 Pro",
		"Oppo Reno Lite",
		"Oppo Reno 2 Lite",
		"Oppo Reno 3 Lite",
		"Oppo Reno 4 Lite",
		"Oppo Reno 5 Lite",
		"Oppo Reno 6 Lite",
		"Oppo Reno 7 Lite",
		"Oppo Reno 8 Lite",
		"Oppo Reno 9 Lite",
		"Oppo Reno 10 Lite",
		"Oppo A3",
		"Oppo A5",
		"Oppo A7",
		"Oppo A9",
		"Oppo A11",
		"Oppo A12",
		"Oppo A15",
		"Oppo A16",
		"Oppo A31",
		"Oppo A32",
		"Oppo A33",
		"Oppo A52",
		"Oppo A53",
		"Oppo A72",
		"Oppo A73",
		"Oppo A74",
		"Oppo A76",
		"Oppo A77",
		"Oppo A78",
		"Oppo K3",
		"Oppo K5",
		"Oppo K7",
		"Oppo K9",
		"Oppo K10",
		"OnePlus One",
		"OnePlus 2",
		"OnePlus 3",
		"OnePlus 3T",
		"OnePlus 5",
		"OnePlus 5T",
		"OnePlus 6",
		"OnePlus 6T",
		"OnePlus 7",
		"OnePlus 7 Pro",
		"OnePlus 7T",
		"OnePlus 7T Pro",
		"OnePlus 8",
		"OnePlus 8 Pro",
		"OnePlus 8T",
		"OnePlus 9",
		"OnePlus 9 Pro",
		"OnePlus 10 Pro",
		"OnePlus 11",
		"OnePlus Nord",
		"OnePlus Nord CE",
		"OnePlus Nord N10",
		"OnePlus Nord N100",
		"OnePlus Nord 2",
		"OnePlus Nord CE 2",
		"OnePlus Nord CE 3",
		"OnePlus Nord 3",
		"Honor 6",
		"Honor 7",
		"Honor 8",
		"Honor 9",
		"Honor 10",
		"Honor 20",
		"Honor 30",
		"Honor 50",
		"Honor 60",
		"Honor 70",
		"Honor 80",
		"Honor 90",
		"Honor 6 Pro",
		"Honor 7 Pro",
		"Honor 8 Pro",
		"Honor 9 Pro",
		"Honor 10 Pro",
		"Honor 20 Pro",
		"Honor 30 Pro",
		"Honor 50 Pro",
		"Honor 60 Pro",
		"Honor 70 Pro",
		"Honor 80 Pro",
		"Honor 90 Pro",
		"Honor 6 Lite",
		"Honor 7 Lite",
		"Honor 8 Lite",
		"Honor 9 Lite",
		"Honor 10 Lite",
		"Honor 20 Lite",
		"Honor 30 Lite",
		"Honor 50 Lite",
		"Honor 60 Lite",
		"Honor 70 Lite",
		"Honor 80 Lite",
		"Honor 90 Lite",
		"Honor X7",
		"Honor X8",
		"Honor X9",
		"Honor X10",
		"Honor X20",
		"Honor X30",
		"Honor X40",
		"Honor Magic",
		"Honor Magic 2",
		"Honor Magic 3",
		"Honor Magic 4",
		"Honor Magic 5",
		"Honor Magic Pro",
		"Honor Magic 2 Pro",
		"Honor Magic 3 Pro",
		"Honor Magic 4 Pro",
		"Honor Magic 5 Pro",
		"Honor Magic Ultimate",
		"Honor Magic 2 Ultimate",
		"Honor Magic 3 Ultimate",
		"Honor Magic 4 Ultimate",
		"Honor Magic 5 Ultimate",
		"ZTE Axon",
		"ZTE Axon 7",
		"ZTE Axon M",
		"ZTE Axon 9",
		"ZTE Axon 10",
		"ZTE Axon 20",
		"ZTE Axon 30",
		"ZTE Axon 40",
		"ZTE Axon 50",
		"ZTE Axon Pro",
		"ZTE Axon 7 Pro",
		"ZTE Axon M Pro",
		"ZTE Axon 9 Pro",
		"ZTE Axon 10 Pro",
		"ZTE Axon 20 Pro",
		"ZTE Axon 30 Pro",
		"ZTE Axon 40 Pro",
		"ZTE Axon 50 Pro",
		"ZTE Axon Ultra",
		"ZTE Axon 7 Ultra",
		"ZTE Axon M Ultra",
		"ZTE Axon 9 Ultra",
		"ZTE Axon 10 Ultra",
		"ZTE Axon 20 Ultra",
		"ZTE Axon 30 Ultra",
		"ZTE Axon 40 Ultra",
		"ZTE Axon 50 Ultra",
		"ZTE Blade V7",
		"ZTE Blade V8",
		"ZTE Blade V9",
		"ZTE Blade V10",
		"ZTE Blade 11",
		"ZTE Blade A3",
		"ZTE Blade A5",
		"ZTE Blade A7"
	]
	
	ios_versions = [
		"8_0",
		"8_0_2",
		"8_1",
		"8_1_1",
		"8_1_2",
		"8_1_3",
		"8_2",
		"8_3",
		"8_4",
		"8_4_1",
		"9_0",
		"9_0_1",
		"9_0_2",
		"9_1",
		"9_2",
		"9_2_1",
		"9_3",
		"9_3_1",
		"9_3_2",
		"9_3_3",
		"9_3_4",
		"9_3_5",
		"9_3_6",
		"10_0",
		"10_0_1",
		"10_0_2",
		"10_0_3",
		"10_1",
		"10_1_1",
		"10_2",
		"10_2_1",
		"10_3",
		"10_3_1",
		"10_3_2",
		"10_3_3",
		"10_3_4",
		"11_0",
		"11_0_1",
		"11_0_2",
		"11_0_3",
		"11_1",
		"11_1_1",
		"11_1_2",
		"11_2",
		"11_2_1",
		"11_2_2",
		"11_2_5",
		"11_2_6",
		"11_3",
		"11_3_1",
		"11_4",
		"11_4_1",
		"12_0",
		"12_0_1",
		"12_1",
		"12_1_1",
		"12_1_2",
		"12_1_3",
		"12_1_4",
		"12_2",
		"12_3",
		"12_3_1",
		"12_3_2",
		"12_4",
		"12_4_1",
		"12_4_2",
		"12_4_3",
		"12_4_4",
		"12_4_5",
		"12_4_6",
		"12_4_7",
		"12_4_8",
		"12_4_9",
		"12_5",
		"12_5_1",
		"12_5_2",
		"12_5_3",
		"12_5_4",
		"12_5_5",
		"12_5_6",
		"12_5_7",
		"13_0",
		"13_1",
		"13_1_1",
		"13_1_2",
		"13_1_3",
		"13_2",
		"13_2_2",
		"13_2_3",
		"13_3",
		"13_3_1",
		"13_4",
		"13_4_1",
		"13_5",
		"13_5_1",
		"13_6",
		"13_6_1",
		"13_7",
		"14_0",
		"14_0_1",
		"14_1",
		"14_2",
		"14_2_1",
		"14_3",
		"14_4",
		"14_4_1",
		"14_5",
		"14_5_1",
		"14_6",
		"14_7",
		"14_7_1",
		"14_8",
		"14_8_1",
		"15_0",
		"15_0_1",
		"15_0_2",
		"15_1",
		"15_1_1",
		"15_2",
		"15_2_1",
		"15_3",
		"15_3_1",
		"15_4",
		"15_4_1",
		"15_5",
		"15_6",
		"15_6_1",
		"15_7",
		"15_7_1",
		"15_7_2",
		"15_7_3",
		"15_7_4",
		"15_7_5",
		"15_7_6",
		"15_7_7",
		"15_7_8",
		"15_7_9",
		"15_8",
		"15_8_1",
		"15_8_2",
		"15_8_3",
		"16_0",
		"16_0_1",
		"16_1",
		"16_1_1",
		"16_1_2",
		"16_2",
		"16_3",
		"16_3_1",
		"16_4",
		"16_4_1",
		"16_5",
		"16_5_1",
		"16_6",
		"16_6_1",
		"16_7",
		"16_7_1",
		"16_7_2",
		"16_7_4",
		"16_7_5",
		"16_7_6",
		"16_7_7",
		"16_7_8",
		"16_7_9",
		"17_0",
		"17_0_1",
		"17_0_2",
		"17_0_3",
		"17_1",
		"17_1_1",
		"17_1_2",
		"17_2",
		"17_2_1",
		"17_3",
		"17_3_1",
		"17_4",
		"17_4_1",
		"17_5",
		"17_5_1",
		"17_6",
		"17_6_1",
		"18_0",
		"18_0_1",
		"18_1"
	]
	
	ios_devices = [
		("iPhone", "CPU iPhone OS"),
		("iPad", "CPU OS"),
		("iPod touch", "CPU iPhone")
	]


@dataclass(frozen=True)
class UserAgentEngine:
	"""
    A class that holds the different engine specific user agent parts.

    Attributes:
        apple_webkit_versions (list[range]): A list of ranges of numbers for AppleWebKit versions.
        gecko_versions (list[range | list[range]]): A list of ranges of numbers for Gecko versions.
    """
	apple_webkit_versions = [range(500, 615), range(0, 36), range(1, 10)]
	gecko_versions = [
		range(2015, 2024),
		range(1, 12),
		[range(1, 31), range(1, 30), range(1, 29), range(1, 28)]
	]


@dataclass(frozen=True)
class UserAgentBrowser:
	"""
    A class that holds the different browser specific user agent parts.

    Attributes:
        chrome_versions (list[str]): A list of supported Chrome versions.
        firefox_versions (list[str]): A list of supported Firefox versions.
        safari_versions (list[str]): A list of supported Safari versions.
        opera_versions (list[str]): A list of supported Opera versions.
        edge_versions (list[str]): A list of supported Edge versions.
        yandex_versions (list[str]): A list of supported Yandex versions.
    """
	chrome_versions = [
		"132.0.6834.160",
		"131.0.6834.111",
		"127.0.6638.59",
		"127.0.6638.50",
		"127.0.6533.100",
		"127.0.6533.73",
		"126.0.6537.0",
		"126.0.6533.89",
		"126.0.6519.120",
		"126.0.6478.183",
		"126.0.6478.119",
		"126.0.6478.97",
		"126.0.6478.62",
		"126.0.6468.85",
		"125.0.6464.130",
		"125.0.6422.142",
		"125.0.6422.77",
		"125.0.6367.207",
		"124.0.6367.119",
		"124.0.6367.92",
		"123.0.6312.123",
		"123.0.6312.100",
		"123.0.6312.59",
		"122.0.6261.75",
		"122.0.6153.129",
		"122.0.6112.112",
		"120.0.6099.225",
		"120.0.6099.199",
		"120.0.6099.132",
		"119.0.6045.200",
		"119.0.6045.160",
		"118.0.5993.118",
		"118.0.5993.71",
		"117.0.5938.92",
		"117.0.5938.83",
		"116.0.5845.141",
		"115.0.5790.110",
		"114.0.5735.106",
		"114.0.5735.100",
		"113.0.5672.127",
		"113.0.5672.92",
		"112.0.5615.87",
		"111.0.5563.111",
		"111.0.5563.84",
		"111.0.5563.65",
		"111.0.5481.177",
		"110.0.5481.104",
		"110.0.5481.97",
		"110.0.5481.79",
		"109.0.5414.120",
		"109.0.5414.75",
		"109.0.5359.125",
		"108.0.5359.72",
		"108.0.5355.95",
		"108.0.5354.122",
		"107.0.5304.107",
		"107.0.5304.63",
		"106.0.5249.103",
		"106.0.5249.62",
		"105.0.5195.127",
		"105.0.5095.56",
		"105.0.5095.54",
		"105.0.5060.154",
		"104.0.5112.102",
		"103.0.5060.66",
		"103.0.5060.61",
		"103.0.5060.53",
		"101.0.4951.99",
		"101.0.4951.54",
		"100.0.4896.68",
		"100.0.4896.64",
		"99.0.4844.75",
		"98.0.4758.102",
		"98.0.4758.82",
		"97.0.4692.71",
		"97.0.4692.39",
		"96.0.4664.119",
		"96.0.4664.93",
		"96.0.4664.45",
		"95.0.4638.54",
		"95.0.4608.81",
		"94.0.4608.54",
		"93.0.4577.82",
		"93.0.4577.63",
		"92.0.4515.159",
		"91.0.4493.102",
		"89.0.4389.129",
		"81.0.4044.122",
		"81.0.3987.182",
		"80.0.3987.149",
		"80.0.3987.132",
		"80.0.3987.116",
		"79.0.3945.107",
		"74.0.3729.169",
		"74.0.3729.121",
		"69.0.3497.81",
		"59.0.3071.63",
		"57.0.2987.133",
		"57.0.2987.89",
		"56.0.2924.76",
		"55.0.2883.98",
		"52.0.2743.178",
		"52.0.2704.105",
		"52.0.2704.103",
		"51.0.2704.79",
		"50.0.2661.94",
		"50.0.2661.76",
		"50.0.2661.75",
		"49.0.2623.87",
		"49.0.2623.75",
		"49.0.2623.37",
		"49.0.2623.12",
		"48.0.2564.116",
		"48.0.2564.106",
		"48.0.2564.103",
		"47.0.2526.73",
		"47.0.2526.55",
		"46.0.2490.85",
		"46.0.2486.88",
		"46.0.2454.1",
		"45.0.2454.65",
		"45.0.2454.44",
		"43.0.2357.134",
		"42.0.2311.112",
		"42.0.2311.102",
		"42.0.2311.60",
		"42.0.2273.189",
		"42.0.2273.119",
		"40.0.2214.91"
	]
	
	firefox_versions = [
		"134.0.2",
		"134.0.1",
		"133.0.2",
		"133.0.1",
		"132.0.2",
		"132.0.1",
		"131.0.2",
		"131.0.1",
		"130.0.1",
		"129.0.2",
		"129.0.1",
		"128.0",
		"127.0.2",
		"127.0.1",
		"126.0",
		"125.0.1",
		"124.0.1",
		"123.0.1",
		"122.0.1",
		"121.0.1",
		"120.0",
		"119.0.2",
		"119.0.1",
		"118.0.2",
		"118.0.1",
		"117.0",
		"116.0.3",
		"116.0.2",
		"116.0.1",
		"115.0.1",
		"114.0.1",
		"113.0",
		"112.0.1",
		"111.0.1",
		"110.0",
		"109.0.1",
		"108.0",
		"107.0.1",
		"106.0",
		"105.0.3",
		"105.0.1",
		"104.0.2",
		"104.0.1",
		"103.0.2",
		"103.0.1",
		"102.0.1",
		"101.0",
		"100.0.1",
		"99.0.1",
		"98.0",
		"97.0.1",
		"96.0.3",
		"96.0.2",
		"96.0.1",
		"95.0.1",
		"94.0.2",
		"94.0.1",
		"93.0.2",
		"93.0.1",
		"92.0.1",
		"91.0.1",
		"90.0.2",
		"90.0.1",
		"89.0.1",
		"88.0.1",
		"87.0",
		"86.0.1",
		"85.0.2",
		"85.0.1",
		"84.0.2",
		"84.0.1",
		"83.0.1",
		"82.0.1",
		"78.0.2",
		"78.0.1",
		"77.0.1",
		"73.0.1",
		"72.0.1",
		"71.0",
		"69.0.1",
		"68.0.2",
		"68.0.1",
		"67.0",
		"66.0",
		"65.0",
		"64.0",
		"62.0",
		"61.0",
		"60.0",
		"59.0",
		"58.0",
		"57.0",
		"56.0",
		"55.0",
		"54.0",
		"53.0",
		"52.0",
		"51.0",
		"50.0",
		"49.0",
		"48.0",
		"47.0",
		"46.0",
		"45.0",
		"44.0",
		"43.0",
		"42.0",
		"41.0",
		"40.0",
		"39.0",
		"38.0",
		"37.0",
		"36.0",
		"35.0"
	]
	
	safari_versions = [
		"18.3",
		"18.2",
		"18.1.1",
		"18.0.1",
		"18.0",
		"17.6",
		"17.5",
		"17.4.1",
		"17.3.1",
		"17.2.1",
		"17.1",
		"17.0",
		"16.6",
		"16.5.1",
		"16.4",
		"16.3.1",
		"16.2",
		"16.1",
		"16.0",
		"15.6",
		"15.5",
		"15.4",
		"15.3",
		"15.2",
		"15.1",
		"15.0",
		"14.1.2",
		"14.1.1",
		"14.0.3",
		"14.0.2",
		"14.0.1",
		"13.1.2",
		"13.1.1",
		"13.0.5",
		"13.0.4",
		"13.0.3",
		"13.0.2",
		"13.0.1",
		"12.3",
		"12.1.1",
		"12.0.3",
		"12.0.2",
		"12.0.1",
		"11.1.2",
		"11.1.1",
		"11.0.3",
		"11.0.2",
		"11.0.1",
		"10.1.2",
		"10.1.1",
		"10.0.3",
		"10.0.2",
		"10.0.1",
		"9.1.3",
		"9.1.2",
		"9.1.1",
		"9.0.3",
		"9.0.2",
		"9.0.1",
		"8.0.8",
		"8.0.7",
		"8.0.6",
		"8.0.5",
		"8.0.4",
		"8.0.3",
		"8.0.2",
		"8.0.1",
		"7.1.7",
		"7.1.6",
		"7.1.5",
		"7.1.4",
		"7.1.3",
		"7.1.2",
		"7.1.1",
		"7.0.6",
		"7.0.5",
		"7.0.4",
		"7.0.3",
		"7.0.2",
		"7.0.1",
		"6.2.8",
		"6.2.7",
		"6.2.6",
		"6.2.5",
		"6.2.4",
		"6.2.3"
	]
	
	opera_versions = [
		"95.0.4950.82067",
		"95.0.4950.81277",
		"94.5.4942.81339",
		"94.5.4452.81339",
		"94.5.4452.81169",
		"93.4.4920.79688",
		"93.4.4920.79686",
		"93.4.4789.79456",
		"93.4.4789.79427",
		"92.4.4433.78425",
		"92.4.4432.79880",
		"91.4.4392.78689",
		"91.3.4392.78688",
		"91.2.4392.78981",
		"91.1.4392.78640",
		"91.1.4392.78469",
		"90.6.4344.78244",
		"90.6.4344.77666",
		"90.5.4344.77484",
		"90.5.4344.77396",
		"90.4.4344.77484",
		"90.4.4344.77339",
		"90.3.4344.77240",
		"79.9.495.77168",
		"79.9.495.77087",
		"79.8.495.76890",
		"79.8.495.76874",
		"79.8.495.76850",
		"79.7.495.76781",
		"79.7.495.76538",
		"79.7.495.76422",
		"79.6.4143.76259",
		"79.6.495.76433",
		"79.6.495.76330",
		"79.5.4143.75934",
		"79.5.4143.75729",
		"78.4.4156.75607",
		"78.4.4143.75607",
		"78.3.4143.75485",
		"78.2.4143.75368",
		"78.1.4143.75368",
		"78.0.4143.75299",
		"77.5.4095.75179",
		"77.4.4095.74986",
		"77.4.4095.74789",
		"77.3.4095.74759",
		"77.2.4095.74584",
		"77.1.4095.74479",
		"77.0.4095.74321",
		"76.8.4023.73374",
		"76.7.4022.73300",
		"76.7.4022.73299",
		"76.6.4022.73219",
		"76.3.3978.72866",
		"76.2.3978.72489",
		"75.1.3978.72320",
		"75.0.3978.72220",
		"74.3.3922.71992",
		"74.2.3922.71774",
		"74.1.3922.71354",
		"74.1.3922.70199",
		"74.0.3922.70182",
		"73.8.3884.70500",
		"73.1.3844.69816",
		"72.8.3777.72992",
		"72.8.3767.69638",
		"72.7.3767.69547",
		"72.7.3767.69545",
		"72.5.3767.69342",
		"72.4.3767.69269",
		"72.3.3767.68685",
		"72.2.3767.68393",
		"72.1.3767.68311",
		"71.8.3767.68191",
		"71.3.3778.67322",
		"71.2.3778.67195",
		"71.1.3778.67122",
		"71.1.3778.67035",
		"70.3.3653.66287",
		"70.2.3653.66236",
		"70.1.3653.66149",
		"70.0.3653.66031",
		"69.8.3606.65458",
		"69.1.3606.63109",
		"69.0.3606.64982",
		"68.8.3557.64187",
		"68.3.3557.64528",
		"68.2.3557.64219",
		"68.1.3528.64103",
		"67.3.3506.63984",
		"67.1.3506.63168",
		"67.0.3506.63081",
		"66.9.3506.63984",
		"66.5.3449.79005",
		"66.5.3449.78853",
		"66.4.3445.70552",
		"66.4.3445.67625",
		"66.3.3445.62346",
		"66.1.3445.62389",
		"66.1.3388.61420",
		"65.5.3388.61420",
		"65.1.3388.61266",
		"65.0.3368.61046",
		"64.3.3292.20839",
		"64.2.3292.20828",
		"64.1.3292.59829",
		"64.0.3292.59726",
		"63.3.3236.59679",
		"63.2.3236.59679",
		"63.2.3236.58640",
		"63.1.3236.58535",
		"63.0.3236.58473",
		"62.8.3236.57765",
		"62.3.3146.57547",
		"62.1.3146.57313",
		"62.0.3146.57357",
		"61.2.3076.56749",
		"61.1.3076.56625",
		"60.5.3004.65892",
		"60.2.3004.63409",
		"60.1.3004.63238",
		"60.0.3004.63063",
		"60.0.3004.55063",
		"59.1.2926.54067",
		"59.0.2926.53920",
		"58.7.2878.72999",
		"58.7.2878.53482",
		"58.6.2878.53020",
		"58.6.2878.48030",
		"58.2.2878.52737",
		"58.2.2878.52634",
		"58.1.2878.52388",
		"58.0.2878.52320",
		"57.2.2830.52681",
		"57.2.2830.52480",
		"57.1.2795.52377",
		"55.2.2779.50760",
		"55.1.2779.50628",
		"55.0.2779.50560",
		"54.3.2872.50220",
		"54.2.2872.49957",
		"54.1.2872.49909",
		"54.0.2872.49578",
		"53.1.2658.14248",
		"53.0.2651.14117",
		"52.9.2651.14117",
		"52.4.2607.140781",
		"52.3.2571.140547",
		"52.2.2557.139970",
		"52.1.2557.139457",
		"51.3.2551.138727",
		"51.2.2461.138699",
		"51.1.2461.137696",
		"51.0.2461.137501",
		"50.5.2454.202382",
		"50.4.2435.148904",
		"50.4.2435.107255",
		"50.2.2435.146237",
		"50.2.2435.138970",
		"50.1.2435.136970",
		"50.1.2428.438970",
		"50.0.2428.438970",
		"49.8.2413.136249",
		"49.4.2413.136238",
		"49.3.2413.136432",
		"48.3.2331.135054",
		"47.3.2349.120976",
		"47.2.2349.104186",
		"47.1.2349.120358",
		"46.6.2349.120187",
		"46.4.2349.127339",
		"46.3.2349.105321",
		"46.2.2349.125126",
		"46.1.2349.124220",
		"46.0.2349.123330",
		"43.8.2349.12185",
		"43.7.2328.11833",
		"43.6.2349.114522",
		"43.5.2349.113571",
		"43.2.2349.112037",
		"42.6.2349.111506",
		"42.5.2349.110649",
		"42.0.2349.103098",
		"39.1.2256.102083",
		"39.0.2076.100285",
		"39.0.2076.99879",
		"38.5.2022.97426",
		"38.5.2022.95330",
		"38.0.1985.99837",
		"38.0.1985.98068",
		"33.0.2002.97817",
		"33.0.2002.97748",
		"33.0.1953.97349",
		"32.0.1953.95534",
		"32.0.1953.95530",
		"30.0.1856.92967",
		"30.0.1856.92897",
		"29.0.1856.92117",
		"29.0.1808.91837",
		"28.0.1754.89981",
		"27.0.1698.89115",
		"27.0.1698.88647",
		"26.0.1656.87080",
		"26.0.1649.84037",
		"26.0.1649.82559",
		"22.0.1485.91017",
		"22.0.1485.79487",
		"21.0.1482.74904",
		"21.0.1477.75510",
		"21.0.1437.74904",
		"20.0.1405.74047",
		"20.0.1366.73172",
		"19.0.1346.73588",
		"16.0.1212.73520",
		"16.0.1212.69496",
		"16.0.1212.67495",
		"16.0.1212.60583",
		"15.0.1212.66462",
		"14.0.1197.87453",
		"14.0.1197.69541",
		"12.4",
		"12.3",
		"12.2",
		"12.1",
		"12.0",
		"11.5",
		"11.1",
		"11.0"
	]
	
	edge_versions = [
		"132.0.2907.127",
		"131.0.2903.146",
		"131.0.2897.127",
		"131.0.2872.137",
		"131.0.2778.63",
		"131.0.2739.82",
		"130.0.2739.54",
		"130.0.2639.79",
		"130.0.2599.79",
		"127.0.2739.54",
		"127.0.2651.86",
		"127.0.2631.98",
		"127.0.2592.87",
		"126.0.2592.68",
		"125.0.2535.92",
		"125.0.2535.85",
		"124.0.2478.67",
		"123.0.2420.65",
		"122.0.2365.92",
		"122.0.2365.66",
		"122.0.2356.52",
		"122.0.2271.106",
		"120.0.2210.91",
		"119.0.2151.72",
		"117.0.2045.41",
		"116.0.1882.82",
		"116.0.1882.67",
		"116.0.1835.55",
		"116.0.1823.45",
		"116.0.1822.57",
		"115.0.1901.183",
		"115.0.1901.123",
		"115.0.1901.100",
		"115.0.1774.53",
		"115.0.1754.35",
		"115.0.1732.48",
		"115.0.1732.34",
		"115.0.1732.19",
		"111.0.1661.54",
		"111.0.1627.89",
		"110.0.1587.83",
		"110.0.1587.57",
		"109.0.1518.91",
		"109.0.1518.81",
		"109.0.1518.52",
		"109.0.1463.76",
		"108.0.1463.46",
		"107.0.1463.62",
		"107.0.1463.32",
		"107.0.1418.42",
		"107.0.1418.34",
		"107.0.1378.47",
		"106.0.1370.34",
		"105.0.1343.42",
		"105.0.1343.30",
		"104.0.1293.54",
		"104.0.1293.47",
		"103.0.1264.62",
		"103.0.1264.49",
		"102.0.1245.44",
		"102.0.1245.30",
		"102.0.1210.47",
		"100.0.1185.36",
		"100.0.1150.46",
		"98.0.1108.62",
		"98.0.1108.43",
		"97.0.1072.69",
		"97.0.1072.62",
		"97.0.1072.55",
		"96.0.1054.53",
		"96.0.1054.41",
		"95.0.1020.53",
		"94.0.992.50",
		"94.0.992.37",
		"94.0.992.31",
		"92.0.902.55",
		"91.0.864.71",
		"91.0.864.70",
		"91.0.864.55",
		"91.0.818.63",
		"89.0.774.59",
		"89.0.774.55",
		"87.0.664.69",
		"87.0.664.63",
		"86.0.623.68",
		"86.0.622.96",
		"86.0.622.48",
		"86.0.564.44",
		"85.0.522.81",
		"84.0.522.58",
		"84.0.522.52",
		"84.0.522.40",
		"83.0.478.64",
		"83.0.478.59",
		"81.0.478.37",
		"81.0.416.77",
		"81.0.416.62",
		"81.0.416.58",
		"81.0.416.34",
		"80.0.361.109",
		"80.0.361.62",
		"80.0.361.49",
		"80.0.361.48",
		"79.0.309.71",
		"79.0.309.68",
		"79.0.309.65",
		"79.0.309.35",
		"79.0.309.1"
	]
	
	yandex_versions = [
		"24.12.2",
		"24.12.1",
		"24.10.3",
		"24.10.1",
		"24.9.1",
		"24.8.5",
		"24.8.3",
		"24.7.4",
		"24.6.6",
		"24.6.5",
		"24.6.4",
		"24.6.3",
		"24.4.2",
		"24.1.15",
		"24.1.14",
		"24.1.2",
		"24.1.1",
		"23.11.3",
		"23.11.2",
		"23.11.1",
		"23.9.2",
		"23.9.0",
		"23.7.3",
		"23.7.1",
		"23.7.0",
		"23.5.8",
		"23.5.0",
		"23.1.6",
		"23.1.5",
		"23.1.3",
		"23.1.1",
		"22.11.5",
		"22.10.1",
		"22.7.2",
		"22.4.5",
		"22.4.1",
		"22.3.2",
		"22.1.5",
		"22.1.3",
		"22.1.2",
		"22.1.1",
		"22.1.0",
		"21.12.6",
		"21.8.5",
		"21.8.1",
		"21.6.4",
		"21.6.3",
		"21.6.0",
		"21.5.5",
		"21.5.4",
		"21.5.2",
		"21.5.0",
		"21.3.3",
		"21.3.2",
		"21.3.0",
		"21.2.4",
		"21.2.2",
		"20.12.2",
		"20.12.1",
		"20.12.0.966",
		"20.11.3",
		"20.11.2",
		"20.9.6",
		"20.9.3",
		"20.9.2",
		"20.8.1",
		"20.8.0",
		"20.7.1",
		"20.7.0",
		"20.4.2",
		"20.3.2",
		"19.12.2",
		"19.12.0",
		"19.10.1",
		"16.10.0",
		"15.4"
	]
